pytest_sauce
============

To install this package, download code, and run `python setup.py develop` or `python setup.py install`

Once it's packaged on egg end deployed on some pypi, it'll be enough to add it to your project's requirements, or install it by means of pip.

Contents
--------

.. toctree::
   :maxdepth: 2

   basic
   advanced
   api
   AUTHORS


TODO
----

#. create a console tasks to run tests
